==> envision-0.1.0-20141104.095440-2.jar: assets/cljs/main.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.array', 'goog.object', 'goog.string.StringBuffer']);
goog.addDependency("../clojurewerkz/envisioncljs/utils.js", ['clojurewerkz.envisioncljs.utils'], ['cljs.core']);
goog.addDependency("../schema/utils.js", ['schema.utils'], ['cljs.core', 'goog.string', 'goog.string.format']);
goog.addDependency("../reagent/ratom.js", ['reagent.ratom'], ['cljs.core']);
goog.addDependency("../reagent/debug.js", ['reagent.debug'], ['cljs.core']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['cljs.core', 'goog.string', 'goog.string.StringBuffer']);
goog.addDependency("../reagent/impl/reactimport.js", ['reagent.impl.reactimport'], ['cljs.core']);
goog.addDependency("../reagent/impl/util.js", ['reagent.impl.util'], ['cljs.core', 'reagent.debug', 'clojure.string', 'reagent.impl.reactimport']);
goog.addDependency("../reagent/impl/batching.js", ['reagent.impl.batching'], ['cljs.core', 'reagent.debug', 'clojure.string', 'reagent.impl.util', 'reagent.ratom']);
goog.addDependency("../reagent/impl/component.js", ['reagent.impl.component'], ['cljs.core', 'reagent.debug', 'reagent.impl.util', 'reagent.impl.batching', 'reagent.ratom']);
goog.addDependency("../reagent/impl/template.js", ['reagent.impl.template'], ['cljs.core', 'reagent.debug', 'clojure.string', 'reagent.impl.component', 'reagent.impl.util', 'reagent.impl.batching', 'reagent.ratom']);
goog.addDependency("../schema/core.js", ['schema.core'], ['cljs.core', 'schema.utils', 'clojure.string']);
goog.addDependency("../clojurewerkz/envisioncljs/dimple.js", ['clojurewerkz.envisioncljs.dimple'], ['schema.core', 'cljs.core']);
goog.addDependency("../clojurewerkz/envisioncljs/chart_config.js", ['clojurewerkz.envisioncljs.chart_config'], ['schema.core', 'cljs.core']);
goog.addDependency("../reagent/core.js", ['reagent.core'], ['reagent.impl.template', 'cljs.core', 'reagent.impl.component', 'reagent.impl.util', 'reagent.impl.batching', 'reagent.ratom']);
goog.addDependency("../clojurewerkz/envisioncljs/button.js", ['clojurewerkz.envisioncljs.button'], ['cljs.core', 'reagent.core']);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../clojurewerkz/envisioncljs/chart.js", ['clojurewerkz.envisioncljs.chart'], ['schema.core', 'clojurewerkz.envisioncljs.chart_config', 'cljs.core', 'clojurewerkz.envisioncljs.utils', 'reagent.core', 'clojurewerkz.envisioncljs.button', 'clojure.set', 'clojurewerkz.envisioncljs.dimple']);

==> envision-0.1.0-20150510.132354-5.jar: assets/cljs/main.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.array', 'goog.object', 'goog.string.StringBuffer']);
goog.addDependency("../clojurewerkz/envisioncljs/utils.js", ['clojurewerkz.envisioncljs.utils'], ['cljs.core']);
goog.addDependency("../schema/utils.js", ['schema.utils'], ['cljs.core', 'goog.string', 'goog.string.format']);
goog.addDependency("../reagent/ratom.js", ['reagent.ratom'], ['cljs.core']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['cljs.core', 'goog.string', 'goog.string.StringBuffer']);
goog.addDependency("../schema/core.js", ['schema.core'], ['cljs.core', 'schema.utils', 'clojure.string']);
goog.addDependency("../clojurewerkz/envisioncljs/chart_config.js", ['clojurewerkz.envisioncljs.chart_config'], ['schema.core', 'cljs.core']);
goog.addDependency("../reagent/debug.js", ['reagent.debug'], ['cljs.core']);
goog.addDependency("../reagent/impl/reactimport.js", ['reagent.impl.reactimport'], ['cljs.core']);
goog.addDependency("../reagent/impl/util.js", ['reagent.impl.util'], ['cljs.core', 'reagent.debug', 'clojure.string', 'reagent.impl.reactimport']);
goog.addDependency("../reagent/impl/batching.js", ['reagent.impl.batching'], ['cljs.core', 'reagent.debug', 'clojure.string', 'reagent.impl.util', 'reagent.ratom']);
goog.addDependency("../reagent/impl/component.js", ['reagent.impl.component'], ['cljs.core', 'reagent.debug', 'reagent.impl.util', 'reagent.impl.batching', 'reagent.ratom']);
goog.addDependency("../reagent/impl/template.js", ['reagent.impl.template'], ['cljs.core', 'reagent.debug', 'clojure.string', 'reagent.impl.component', 'reagent.impl.util', 'reagent.impl.batching', 'reagent.ratom']);
goog.addDependency("../reagent/core.js", ['reagent.core'], ['reagent.impl.template', 'cljs.core', 'reagent.impl.component', 'reagent.impl.util', 'reagent.impl.batching', 'reagent.ratom']);
goog.addDependency("../clojurewerkz/envisioncljs/button.js", ['clojurewerkz.envisioncljs.button'], ['cljs.core', 'reagent.core']);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../clojurewerkz/envisioncljs/dimple.js", ['clojurewerkz.envisioncljs.dimple'], ['schema.core', 'clojurewerkz.envisioncljs.chart_config', 'cljs.core']);
goog.addDependency("../clojurewerkz/envisioncljs/chart.js", ['clojurewerkz.envisioncljs.chart'], ['schema.core', 'clojurewerkz.envisioncljs.chart_config', 'cljs.core', 'clojurewerkz.envisioncljs.utils', 'reagent.core', 'clojurewerkz.envisioncljs.button', 'clojure.set', 'clojurewerkz.envisioncljs.dimple']);
goog.addDependency("../clojurewerkz/envisioncljs/core.js", ['clojurewerkz.envisioncljs.core'], ['schema.core', 'clojurewerkz.envisioncljs.chart_config', 'cljs.core', 'clojurewerkz.envisioncljs.utils', 'reagent.core', 'clojurewerkz.envisioncljs.button', 'clojure.set', 'clojurewerkz.envisioncljs.dimple', 'clojurewerkz.envisioncljs.chart']);
goog.addDependency("../cljs/reader.js", ['cljs.reader'], ['cljs.core', 'goog.string']);
goog.addDependency("../clojurewerkz/envisioncljs/continuum/main.js", ['clojurewerkz.envisioncljs.continuum.main'], ['schema.core', 'goog.Timer', 'clojurewerkz.envisioncljs.chart_config', 'cljs.core', 'clojurewerkz.envisioncljs.utils', 'reagent.core', 'clojurewerkz.envisioncljs.button', 'cljs.reader', 'clojure.set', 'clojurewerkz.envisioncljs.dimple', 'goog.events', 'clojurewerkz.envisioncljs.chart']);
